@@ -17,19 +17,24 @@ kernel_type <- function(kern) {
 process_options <- function(M, se.method, method, d, kern) {
     if (kernel_type(kern)=="optimal" && method!="SRD")
         stop("Optimal kernel requires sharp RD design.")
+    m_len <- if (method=="FRD") 2 else 1
     if (!missing(M)) {
-        m_len <- if (method=="FRD") 2 else 1
         if (!check_positive(M, m_len))
             stop(paste0("M must be a non-negative numeric vector of length",
                         m_len, "."))
     }
+
+    if (method=="IP") {
+        if (!is.null(d$covs))
+            stop("Covariates not allowed whem method is 'IP'.")
+    } else if (min(sum(d$p), sum(d$m))==0) {
+        stop("No observations on one side of the cutoff")
+    }
+
     if (!(se.method %in% c("nn", "EHW", "supplied.var"))) {
         stop("Unsupported se.method")
     }
     if (se.method=="nn" && !is.null(d$clusterid))
         stop(paste0("'se.method=\"nn\"' not allowed with clustered standard",
                     "  errors.\nUse 'se.method=\"EHW\"'"))
-
-    if (!is.null(d$covs) && method=="IP")
-        stop("Covariates not allowed whem method is 'IP'.")
 }
